pub struct AgentHandle { /* private fields */ }Expand description
A handle to the agent that can be used by the interpreter.
This is cloneable so it can be passed to different interpreter threads. Uses tokio’s UnboundedSender which allows non-blocking sends from sync code.
Implementations
Sourceimpl AgentHandle
impl AgentHandle
Sourcepub fn new(tx: UnboundedSender<ThinkRequest>) -> Self
pub fn new(tx: UnboundedSender<ThinkRequest>) -> Self
Create a new agent handle from a sender.
Sourcepub fn think(
&self,
prompt: String,
bindings: HashMap<String, Value>,
expect: String,
) -> Result<Receiver<ThinkResponse>, String>
pub fn think( &self, prompt: String, bindings: HashMap<String, Value>, expect: String, ) -> Result<Receiver<ThinkResponse>, String>
Send a think request to the agent.
Returns a receiver for ThinkResponse messages. The send is non-blocking (uses tokio unbounded channel), but the returned receiver is std::sync for blocking receive.